Deletes all locally cached FRED data files. The next call to any data function will re-download from the FRED API.
See also
Other configuration:
fred_cache_info(),
fred_get_key(),
fred_request(),
fred_set_key()
Deletes all locally cached FRED data files. The next call to any data function will re-download from the FRED API.
Other configuration:
fred_cache_info(),
fred_get_key(),
fred_request(),
fred_set_key()