fars_map_state: Plot data accident

Description Usage Arguments Value Note Examples

View source: R/fars_functions.R

Description

This functions allow to plot the longitude and latitude of the accidents that happend in a specific state in a specific year

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

an integer that represent the number of a state.

year

an integer that represent a year.

Value

This function returns a graph where can be seen the location (latitude and longitude) of the accident that happend in the state in the year entered.

Note

This function will generate an error if the year or state does not exists in the database.

Examples

1
fars_map_state(27,2013)

Fr3ddy1/FRED documentation built on May 7, 2019, 8:05 a.m.