fars_read: Read a compressed file.

Description Usage Arguments Value Note Examples

View source: R/fars_functions.R

Description

This functions allow to read a compressed (.bz2) or a csv file.

Usage

1
fars_read(filename)

Arguments

filename

A caracter that contains the name of the file with its respective extension.

Value

This function returns the read data in a "dataframe", "tbl_df", "tbl" format.

Note

This function will generate an error if the filemane is wrong or have a wrong extension.

Examples

1
2
3
4

Fr3ddy1/FRED documentation built on May 7, 2019, 8:05 a.m.