fars_read_years: Select specific variables of the data.

Description Usage Arguments Value Note Examples

View source: R/fars_functions.R

Description

This functions allow to select the variable "MONTH" and "YEAR" from the data for the accidents that happend in the year or years entered.

Usage

1

Arguments

years

an integer that represent a year or years.

Value

This function returns a list with the variable "MONTH" and "YEAR" for the year or years entered.

Note

This function will generate an warning message if the year or years entered does not exists in the database.

Examples

1
2
fars_read_years(c(2013,2014))
fars_read_years(2013)

Fr3ddy1/FRED documentation built on May 7, 2019, 8:05 a.m.