fars_summarize_years: Sumarize accidents by month of a specific year

Description Usage Arguments Value Note Examples

View source: R/fars_functions.R

Description

This functions allow to generate a summary of the accidents that happend in a specific year or years.

Usage

1

Arguments

years

an integer that represent a year or years.

Value

This function returns a summary for every month of every year in a "dataframe", "tbl_df", "tbl" format.

Note

This function will generate an warning message if the year or years entered does not exists in the database.

Examples

1
2
fars_summarize_years(c(2013,2014))
fars_summarize_years(c(2013,2015))

Fr3ddy1/FRED documentation built on May 7, 2019, 8:05 a.m.