make_filename: Create a filename.

Description Usage Arguments Value Note Examples

View source: R/fars_functions.R

Description

This functions allow to create a character with a filename, that will have a "csv.bz2" extension. The filename will always be "accident_*.csv.bz2", with the only diference that "*" will be replace by the entered year.

Usage

1

Arguments

year

an integer that represent a year.

Value

This function returns a caracter with a filename.

Note

This function will generate an warning message if the parameter "year" is a character instead a integer.

Examples

1
2

Fr3ddy1/FRED documentation built on May 7, 2019, 8:05 a.m.