Description Usage Arguments Value Note Examples
View source: R/fars_functions.R
This functions allow to plot the longitude and latitude of the accidents that happend in a specific state in a specific year
1 | fars_map_state(state.num, year)
|
state.num |
an integer that represent the number of a state. |
year |
an integer that represent a year. |
This function returns a graph where can be seen the location (latitude and longitude) of the accident that happend in the state in the year entered.
This function will generate an error if the year or state does not exists in the database.
1 | fars_map_state(27,2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.