Description Usage Arguments Value Note Examples
View source: R/fars_functions.R
This functions allow to read a compressed (.bz2) or a csv file.
1 | fars_read(filename)
|
filename |
A caracter that contains the name of the file with its respective extension. |
This function returns the read data in a "dataframe", "tbl_df", "tbl" format.
This function will generate an error if the filemane is wrong or have a wrong extension.
1 2 3 4 | library(dplyr)
library(readr)
fars_read(make_filename(2013))
fars_read(make_filename(2014))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.