Description Usage Arguments Value Note Examples
View source: R/fars_functions.R
This functions allow to select the variable "MONTH" and "YEAR" from the data for the accidents that happend in the year or years entered.
1 | fars_read_years(years)
|
years |
an integer that represent a year or years. |
This function returns a list with the variable "MONTH" and "YEAR" for the year or years entered.
This function will generate an warning message if the year or years entered does not exists in the database.
1 2 | fars_read_years(c(2013,2014))
fars_read_years(2013)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.