Description Usage Arguments Value Note Examples
View source: R/fars_functions.R
This functions allow to generate a summary of the accidents that happend in a specific year or years.
1 | fars_summarize_years(years)
|
years |
an integer that represent a year or years. |
This function returns a summary for every month of every year in a "dataframe", "tbl_df", "tbl" format.
This function will generate an warning message if the year or years entered does not exists in the database.
1 2 | fars_summarize_years(c(2013,2014))
fars_summarize_years(c(2013,2015))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.