fred_related_tags: Find tags related to a given tag

View source: R/tags.R

fred_related_tagsR Documentation

Description

Returns tags that are frequently used together with the specified tag.

Usage

fred_related_tags(tag_names)

Arguments

tag_names

Character. One or more tag names, separated by semicolons (e.g. "gdp", "usa;quarterly").

Value

A data frame of related tags.

See Also

Other tags: fred_tags()

Examples


op <- options(fred.cache_dir = tempdir())
fred_related_tags("gdp")
options(op)


fred documentation built on March 19, 2026, 5:09 p.m.