| fred_release_dates | R Documentation |
Returns the dates on which data for a release were published. Useful for understanding the data calendar and when revisions occurred.
fred_release_dates(release_id)
release_id |
Integer. The release ID. |
A data frame with columns release_id and date.
Other releases:
fred_release_series(),
fred_releases()
op <- options(fred.cache_dir = tempdir())
fred_release_dates(53)
options(op)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.