| fred_request | R Documentation |
Low-level function that sends a request to any FRED API endpoint and
returns the parsed JSON as a list. Most users should use the higher-level
functions such as fred_series() or fred_search().
fred_request(endpoint, ...)
endpoint |
Character. The API endpoint path (e.g.
|
... |
Named parameters passed as query string arguments to the API. |
A list parsed from the JSON response.
Other configuration:
clear_cache(),
fred_get_key(),
fred_set_key()
op <- options(fred.cache_dir = tempdir())
fred_request("series", series_id = "GDP")
options(op)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.