| fred_sources | R Documentation |
Returns all data sources that contribute series to FRED. Sources include the Bureau of Labor Statistics, Bureau of Economic Analysis, Federal Reserve Board, U.S. Census Bureau, and over 100 others.
fred_sources()
A data frame of sources with columns including id, name,
and link.
Other sources:
fred_source_releases()
op <- options(fred.cache_dir = tempdir())
fred_sources()
options(op)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.