Description Usage Arguments Value Note Examples
View source: R/fars_functions.R
This functions allow to create a character with a filename, that will have a "csv.bz2" extension. The filename will always be "accident_*.csv.bz2", with the only diference that "*" will be replace by the entered year.
1 | make_filename(year)
|
year |
an integer that represent a year. |
This function returns a caracter with a filename.
This function will generate an warning message if the parameter "year" is a character instead a integer.
1 2 | make_filename(2013)
make_filename(2014)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.